#
# spec file for package python-minio
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-minio
Version:        5.0.8
Release:        lp152.1.1
Summary:        Minio library for Amazon S3 compatible cloud storage
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/minio/minio-py
Source:         https://files.pythonhosted.org/packages/source/m/minio/minio-%{version}.tar.gz
# https://github.com/minio/minio-py/issues/865
Source1:        https://raw.githubusercontent.com/minio/minio-py/master/minio/credentials/config.json.sample
Source2:        https://raw.githubusercontent.com/minio/minio-py/master/minio/credentials/credentials.sample
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-certifi
Requires:       python-future
Requires:       python-python-dateutil
Requires:       python-pytz
Requires:       python-urllib3
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Faker}
BuildRequires:  %{python_module certifi}
BuildRequires:  %{python_module future}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module urllib3}
# /SECTION
%python_subpackages

%description
Minio library for Amazon S3 compatible cloud storage.

%prep
%setup -q -n minio-%{version}
mv docs/zh_CN/API.md docs/API_zh_CN.md
sed -i -e '/configparser/d' setup.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
cp %{SOURCE1} %{SOURCE2} minio/credentials
%pytest

%files %{python_files}
%doc README*.md docs/API*.md examples/
%license LICENSE
%{python_sitelib}/*

%changelog
* Wed Apr  1 2020 pgajdos@suse.com
- version update to 5.0.8
  * Fixes not subscriptable objects (#858) (03/09/20)
  * Support to put/get/delete default encryption configuration apis on a bucket (#855) (02/24/20)
  * Fix deprecation warnings due to invalid escape sequences. (#853) (02/10/20)
  * Add support for Amazon S3 Transfer Acceleration for presigned urls (#827) (02/02/20)
  * Add note on concurrent usage of Minio client (#849) (02/01/20)
  * python 3.8 compatibility (#847) (01/27/20)
  * cleanup whitespace and fix license header (#845) (01/22/20)
  * fix: relax bucket_name validation for existing buckets (#840) (01/22/20)
  * Implement credentials object (similar to minio-go) to enable AWS IAM (#817) (01/22/20)
- added sources
  https://github.com/minio/minio-py/issues/865
  + config.json.sample
  + credentials.sample
* Wed Jan 22 2020 Martin Sirringhaus <martin.sirringhaus@suse.com>
- Update to 5.0.6
  * Fix detecting a valid endpoint with new Python versions
  * Fix some typo in SELECT API doc
  * fget_object(): open temporary file on overwrite mode
- Update to 5.0.5
  * Increase presigned timeouts for functional tests
  * Remove future depdency for python3
  * Do not need to set max-keys, max-uploads and max-parts
- Update to 5.0.4
  * signV4: Avoid encoding ~ when found in the query part of
    the url
  * FIX: AttributeError at error.message
  * Strip port 80/443 from host
* Tue Oct  1 2019 Marketa Calabkova <mcalabkova@suse.com>
- Update to 5.0.1
  * BREAKING API CHANGE: re-implement select_object_content
  * Remove white-space characters before parsing XML
  * Do not encode ~ in V4 S3 signing
* Wed Sep 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.0.21:
  * Doc: Fix error response URL link
  * Add support for ISO time with and without fractional seconds.
  * ObjectAccessed with Get and Head methods
  * list-objects-v2: Add start_after parameter
  * Implement select object
* Wed Jul 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.0.18:
  * Better error msg if metadata contains a non us-ascii character (#770) (06/12/19)
  * Fix Py3.7 warnings (#767) (06/11/19)
* Fri May 24 2019 pgajdos@suse.com
- version update to 4.0.17
  * Validate underscores in host names successfully
  * Use README.md instead of README.rst
* Fri May 17 2019 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 4.0.16
  * Replaces Minio refs with MinIO and minio.io links with min.io
  * Use optimal part size determined by SDK
  * Adds debug code
* Fri Apr  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.0.13:
  * Add configurable part_size (#745)
* Fri Mar 15 2019 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Add %%license and %%doc
- Update to v4.0.12
  * allow copy_object to set content-type
  * Add support for session tokens
  * Create MANIFEST.in
* Sat Feb 16 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v4.0.11
